@@ -9,7 +9,11 @@ our @EXPORT_OK = ('template');
 sub template {
   my $template = shift;
   
-  return sub { shift->render($template, , 'mojo.maybe' => 1) };
+  return sub {
+    my $self = shift;
+    $self->render($template, 'mojo.maybe' => 1);
+    $self->stash('mojo.finished') ? undef : $self->render_not_found;
+  };
 }
 
 1;
